@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_includes_h =
- *   "$Id: includes.h 4961 2006-09-21 05:14:18Z mwedel $";
+ *   "$Id: includes.h 11673 2009-05-09 05:48:40Z kbulgrien $";
  */
 
 /*
@@ -26,11 +26,16 @@
     The authors can be reached via e-mail at crossfire-devel@real-time.com
 */
 
+/**
+ * @file
+ * Standard includes.
+ */
+
 #ifndef INCLUDES_H
 #define INCLUDES_H
 
 #if defined(osf1) && !defined(__osf__)
-#  define	__osf__
+#  define __osf__
 #endif
 
 #if defined(sgi) && !defined(__sgi__)
@@ -98,7 +103,8 @@
 #include "config.h"
 #include "define.h"
 #include "logger.h"
-#include "newclient.h"
+#include "shared/newclient.h"
+#include "languages.h"
 
 #ifndef TRUE
 #define TRUE 1
@@ -113,6 +119,4 @@ size_t strftime(char *, size_t, const char *, const struct tm *);
 time_t mktime(struct tm *);
 #endif
 
-
 #endif /* INCLUDES_H */
-
