@@ -3,6 +3,12 @@
 /* This code is placed under the GPL.                                        */
 /*****************************************************************************/
 
+/**
+ * @file
+ * Definitions for the plugin system.
+ * @todo link to plugin stuff when the documentation exists in doxygen form :) remove commented things line 329+.
+ */
+
 /*****************************************************************************/
 /* Headers needed.                                                           */
 /*****************************************************************************/
@@ -38,57 +44,57 @@
 #include <../random_maps/random_map.h>
 #include <../random_maps/rproto.h>
 
-
-/*****************************************************************************/
-/* This one does not exist under Win32.                                      */
-/*****************************************************************************/
+/*******************************************************************************/
+/* This one does not exist under Win32.                                        */
+/*******************************************************************************/
 #ifndef WIN32
 #include <dirent.h>
 #endif
 
-/*****************************************************************************/
-/* Event ID codes. I sorted them to present local events first, but it is    */
-/* just a 'cosmetic' thing.                                                  */
-/*****************************************************************************/
-/*****************************************************************************/
-/* Local events. Those are always linked to a specific object.               */
-/*****************************************************************************/
-#define EVENT_NONE     0  /* No event. This exists only to reserve the "0".  */
-#define EVENT_APPLY    1  /* Object applied-unapplied.                       */
-#define EVENT_ATTACK   2  /* Monster attacked or Scripted Weapon used.       */
-#define EVENT_DEATH    3  /* Player or monster dead.                         */
-#define EVENT_DROP     4  /* Object dropped on the floor.                    */
-#define EVENT_PICKUP   5  /* Object picked up.                               */
-#define EVENT_SAY      6  /* Someone speaks.                                 */
-#define EVENT_STOP     7  /* Thrown object stopped.                          */
-#define EVENT_TIME     8  /* Triggered each time the object can react/move.  */
-#define EVENT_THROW    9  /* Object is thrown.                               */
-#define EVENT_TRIGGER  10 /* Button pushed, lever pulled, etc.               */
-#define EVENT_CLOSE    11 /* Container closed.                               */
-#define EVENT_TIMER    12 /* Timer connected triggered it.                   */
-#define EVENT_DESTROY  13 /* Object destroyed (includes map reset/swapout)   */
-/*****************************************************************************/
-/* Global events. Those are never linked to a specific object.               */
-/*****************************************************************************/
-#define EVENT_BORN     14 /* A new character has been created.               */
-#define EVENT_CLOCK    15 /* Global time event.                              */
-#define EVENT_CRASH    16 /* Triggered when the server crashes. Not recursive*/
-#define EVENT_PLAYER_DEATH  17 /* Global Death event                         */
-#define EVENT_GKILL    18 /* Triggered when anything got killed by anyone.   */
-#define EVENT_LOGIN    19 /* Player login.                                   */
-#define EVENT_LOGOUT   20 /* Player logout.                                  */
-#define EVENT_MAPENTER 21 /* A player entered a map.                         */
-#define EVENT_MAPLEAVE 22 /* A player left a map.                            */
-#define EVENT_MAPRESET 23 /* A map is resetting.                             */
-#define EVENT_REMOVE   24 /* A Player character has been removed.            */
-#define EVENT_SHOUT    25 /* A player 'shout' something.                     */
-#define EVENT_TELL     26 /* A player 'tell' something.                      */
-#define EVENT_MUZZLE   27 /* A player was Muzzled (no_shout set).            */
-#define EVENT_KICK     28 /* A player was Kicked by a DM                     */
-#define EVENT_MAPUNLOAD     29 /* A map is freed (includes swapping out)     */
-#define EVENT_MAPLOAD       30 /* A map is loaded                            */
-
-#define NR_EVENTS 31
+/*******************************************************************************/
+/* Event ID codes. I sorted them to present local events first, but it is      */
+/* just a 'cosmetic' thing.                                                    */
+/*******************************************************************************/
+/*******************************************************************************/
+/* Local events. Those are always linked to a specific object.                 */
+/*******************************************************************************/
+#define EVENT_NONE      0  /**< No event. This exists only to reserve the "0". */
+#define EVENT_APPLY     1  /**< Object applied-unapplied.                      */
+#define EVENT_ATTACK    2  /**< Monster attacked or Scripted Weapon used.      */
+#define EVENT_DEATH     3  /**< Player or monster dead.                        */
+#define EVENT_DROP      4  /**< Object dropped on the floor.                   */
+#define EVENT_PICKUP    5  /**< Object picked up.                              */
+#define EVENT_SAY       6  /**< Someone speaks.                                */
+#define EVENT_STOP      7  /**< Thrown object stopped.                         */
+#define EVENT_TIME      8  /**< Triggered each time the object can react/move. */
+#define EVENT_THROW     9  /**< Object is thrown.                              */
+#define EVENT_TRIGGER   10 /**< Button pushed, lever pulled, etc.              */
+#define EVENT_CLOSE     11 /**< Container closed.                              */
+#define EVENT_TIMER     12 /**< Timer connected triggered it.                  */
+#define EVENT_DESTROY   13 /**< Object destroyed (includes map reset/swapout)  */
+#define EVENT_USER      31 /**< User-defined event.                            */
+#define EVENT_SELLING   32 /**< Object is being sold by another one.           */
+/*******************************************************************************/
+/* Global events. Those are never linked to a specific object.                 */
+/*******************************************************************************/
+#define EVENT_BORN      14 /**< A new character has been created.              */
+#define EVENT_CLOCK     15 /**< Global time event.                             */
+#define EVENT_CRASH     16 /**< Triggered when the server crashes. Not recursive */
+#define EVENT_PLAYER_DEATH  17 /**< Global Death event                         */
+#define EVENT_GKILL     18 /**< Triggered when anything got killed by anyone.  */
+#define EVENT_LOGIN     19 /**< Player login.                                  */
+#define EVENT_LOGOUT    20 /**< Player logout.                                 */
+#define EVENT_MAPENTER  21 /**< A player entered a map.                        */
+#define EVENT_MAPLEAVE  22 /**< A player left a map.                           */
+#define EVENT_MAPRESET  23 /**< A map is resetting.                            */
+#define EVENT_REMOVE    24 /**< A Player character has been removed.           */
+#define EVENT_SHOUT     25 /**< A player 'shout' something.                    */
+#define EVENT_TELL      26 /**< A player 'tell' something.                     */
+#define EVENT_MUZZLE    27 /**< A player was Muzzled (no_shout set).           */
+#define EVENT_KICK      28 /**< A player was Kicked by a DM                    */
+#define EVENT_MAPUNLOAD 29 /**< A map is freed (includes swapping out)         */
+#define EVENT_MAPLOAD   30 /**< A map is loaded                                */
+#define NR_EVENTS 33
 
 #include <stdarg.h>
 
@@ -112,47 +118,50 @@
 #define CFAPI_SSTRING 17 /* Shared string that shouldn't be changed, or const char* */
 #define CFAPI_MOVETYPE 18 /* MoveType */
 
-typedef void* (*f_plug_api) (int* type, ...);
-typedef int   (*f_plug_postinit) (void);
-typedef int   (*f_plug_init)(const char* iversion, f_plug_api gethooksptr);
+/** General API function. */
+typedef void *(*f_plug_api)(int *type, ...);
+/** Function called after the plugin was initialized. */
+typedef int (*f_plug_postinit)(void);
+/** First function called in a plugin. */
+typedef int (*f_plug_init)(const char *iversion, f_plug_api gethooksptr);
 
 #ifndef WIN32
-#define LIBPTRTYPE void*
+#define LIBPTRTYPE void *
 #else
+/** Library handle. */
 #define LIBPTRTYPE HMODULE
 #endif
 
-typedef struct _crossfire_plugin
-{
-    f_plug_api      eventfunc;          /* Event Handler function            */
-    f_plug_api      propfunc;           /* Plugin getProperty function       */
-    f_plug_postinit closefunc;          /* Plugin Termination function       */
-    LIBPTRTYPE      libptr;             /* Pointer to the plugin library     */
-    char            id[MAX_BUF];        /* Plugin identification string      */
-    char            fullname[MAX_BUF];  /* Plugin full name                  */
-    f_plug_api      gevent[NR_EVENTS];  /* Global events registered          */
-    struct _crossfire_plugin *next;
-    struct _crossfire_plugin *prev;
+/** One loaded plugin. */
+typedef struct _crossfire_plugin {
+    f_plug_api      eventfunc;          /**< Event Handler function            */
+    f_plug_api      propfunc;           /**< Plugin getProperty function       */
+    f_plug_postinit closefunc;          /**< Plugin Termination function       */
+    LIBPTRTYPE      libptr;             /**< Pointer to the plugin library     */
+    char            id[MAX_BUF];        /**< Plugin identification string      */
+    char            fullname[MAX_BUF];  /**< Plugin full name                  */
+    f_plug_api      gevent[NR_EVENTS];  /**< Global events registered          */
+    struct _crossfire_plugin *next;     /**< Next plugin in list               */
+    struct _crossfire_plugin *prev;     /**< Previous plugin in list           */
 } crossfire_plugin;
 
 extern int plugin_number;
-extern crossfire_plugin* plugins_list;
+extern crossfire_plugin *plugins_list;
 
 #ifdef WIN32
 
 #define plugins_dlopen(fname) LoadLibrary(fname)
 #define plugins_dlclose(lib) FreeLibrary(lib)
-#define plugins_dlsym(lib,name) GetProcAddress(lib,name)
+#define plugins_dlsym(lib, name) GetProcAddress(lib, name)
 
 #else /*WIN32 */
 
-#define plugins_dlopen(fname) dlopen(fname,RTLD_NOW|RTLD_GLOBAL)
-#define plugins_dlclose(lib) dlclose(lib)
-#define plugins_dlsym(lib,name) dlsym(lib,name)
-#define plugins_dlerror() dlerror()
+#define plugins_dlopen(fname) dlopen(fname, RTLD_NOW|RTLD_GLOBAL)   /**< Load a shared library. */
+#define plugins_dlclose(lib) dlclose(lib)                           /**< Unload a shared library. */
+#define plugins_dlsym(lib, name) dlsym(lib, name)                   /**< Get a function from a shared library. */
+#define plugins_dlerror() dlerror()                                 /**< Library error. */
 #endif /* WIN32 */
 
-
 /* OBJECT-RELATED HOOKS */
 
 #define CFAPI_OBJECT_PROP_OB_ABOVE          1
@@ -263,6 +272,7 @@ extern crossfire_plugin* plugins_list;
 #define CFAPI_OBJECT_PROP_MOVE_SLOW         107
 #define CFAPI_OBJECT_PROP_MOVE_SLOW_PENALTY 108
 #define CFAPI_OBJECT_PROP_DURATION          109
+#define CFAPI_OBJECT_PROP_RAW_NAME          110
 
 #define CFAPI_PLAYER_PROP_IP                150
 #define CFAPI_PLAYER_PROP_MARKED_ITEM       151
@@ -271,6 +281,12 @@ extern crossfire_plugin* plugins_list;
 #define CFAPI_PLAYER_PROP_BED_X             154
 #define CFAPI_PLAYER_PROP_BED_Y             155
 #define CFAPI_PLAYER_PROP_NEXT              156
+#define CFAPI_PLAYER_PROP_TITLE             157
+
+#define CFAPI_PLAYER_QUEST_START            0
+#define CFAPI_PLAYER_QUEST_GET_STATE        1
+#define CFAPI_PLAYER_QUEST_SET_STATE        2
+#define CFAPI_PLAYER_QUEST_WAS_COMPLETED    3
 
 #define CFAPI_MAP_PROP_FLAGS                0
 #define CFAPI_MAP_PROP_DIFFICULTY           1
@@ -286,24 +302,16 @@ extern crossfire_plugin* plugins_list;
 #define CFAPI_MAP_PROP_HEIGHT               11
 #define CFAPI_MAP_PROP_ENTER_X              12
 #define CFAPI_MAP_PROP_ENTER_Y              13
-#define CFAPI_MAP_PROP_TEMPERATURE          14
-#define CFAPI_MAP_PROP_PRESSURE             15
-#define CFAPI_MAP_PROP_HUMIDITY             16
-#define CFAPI_MAP_PROP_WINDSPEED            17
-#define CFAPI_MAP_PROP_WINDDIR              18
-#define CFAPI_MAP_PROP_SKY                  19
-#define CFAPI_MAP_PROP_WPARTX               20
-#define CFAPI_MAP_PROP_WPARTY               21
 #define CFAPI_MAP_PROP_MESSAGE              22
 #define CFAPI_MAP_PROP_NEXT                 23
 #define CFAPI_MAP_PROP_REGION               24
 #define CFAPI_MAP_PROP_UNIQUE               25
 
-#define CFAPI_ARCH_PROP_NAME				0
-#define CFAPI_ARCH_PROP_NEXT				1
-#define CFAPI_ARCH_PROP_HEAD				2
-#define CFAPI_ARCH_PROP_MORE				3
-#define CFAPI_ARCH_PROP_CLONE				4
+#define CFAPI_ARCH_PROP_NAME                0
+#define CFAPI_ARCH_PROP_NEXT                1
+#define CFAPI_ARCH_PROP_HEAD                2
+#define CFAPI_ARCH_PROP_MORE                3
+#define CFAPI_ARCH_PROP_CLONE               4
 
 #define CFAPI_PARTY_PROP_NAME               0
 #define CFAPI_PARTY_PROP_NEXT               1
@@ -324,18 +332,18 @@ extern crossfire_plugin* plugins_list;
 /* registerHook      is used to transmit hook pointers from server to plugin.*/
 /* triggerEvent      is called whenever an event occurs.                     */
 /*****************************************************************************/
-/*extern MODULEAPI CFParm* initPlugin(CFParm* PParm);
-extern MODULEAPI CFParm* endPlugin(CFParm* PParm);
-extern MODULEAPI CFParm* getPluginProperty(CFParm* PParm);
-extern MODULEAPI CFParm* registerHook(CFParm* PParm);
-extern MODULEAPI CFParm* triggerEvent(CFParm* PParm);
+/*extern MODULEAPI CFParm *initPlugin(CFParm *PParm);
+extern MODULEAPI CFParm *endPlugin(CFParm *PParm);
+extern MODULEAPI CFParm *getPluginProperty(CFParm *PParm);
+extern MODULEAPI CFParm *registerHook(CFParm *PParm);
+extern MODULEAPI CFParm *triggerEvent(CFParm *PParm);
 */
 
-typedef struct _hook_entry
-{
-    f_plug_api func;
-    int fid;
-    char fname[256];
+/** One function the server exposes to plugins. */
+typedef struct _hook_entry {
+    f_plug_api func;        /**< Function itself. */
+    int fid;                /**< Function identifier. */
+    const char fname[256];  /**< Function name. */
 } hook_entry;
 
 #endif /* PLUGIN_H */
