@@ -75,24 +75,24 @@ close(ARCH);
 if (!$archonly) {
     &info("$bmaps");
     open(BMAPS,">".$bmaps) || &die("cannot open ".$bmaps);
-    binmode(BMAPS);
+	binmode(BMAPS);
     &bmapsOut;
     close(BMAPS);
 
     open(BMAPS,">".$paths) || &die("cannot open ".$paths);
-    binmode(BMAPS);
+	binmode(BMAPS);
     &pathsOut;
     close(BMAPS);
 
     &info("$faces");
     open(FACES,">".$faces) || &die("cannot open ".$faces);
-    binmode(FACES);
+	binmode(FACES);
     &facesOut;
     close(FACES);
 
     &info("$smooths");
     open(SMOOTHS,">".$smooths) || &die("cannot open ".$smooths);
-    binmode(SMOOTHS);
+	binmode(SMOOTHS);
     &smoothOut;
     close(SMOOTHS);
 
@@ -100,27 +100,18 @@ if (!$archonly) {
     # We still support the old consolidated treasure information
     # so copy it over.
     open(TREASURES,">".$treasures) || &die("cannot open ".$treasures);
-    binmode(TREASURES);
+	binmode(TREASURES);
     print TREASURES "#
 # Do not modify this file - any changes will get overwritten.
-# instead, modify the treasures file or the .trs file in the
-# arch directory.\n#
+# instead, modify the .trs file in the arch directory.
+#
 ";
-
-    open(TR, "<treasures");
-    binmode(TR);
-    while (<TR>) {
-	print TREASURES $_;
-    }
-    close(TR);
-    print TREASURES "#\n# Start of collected .trs files\n#\n";
-
     &treasuresOut;
     close(TREASURES);
 
     &info("$animations");
     open(ANIM,">".$animations) || &die("cannot open ".$animations);
-    binmode(ANIM);
+	binmode(ANIM);
     &animOut;
     close(ANIM);
 }
@@ -164,13 +155,13 @@ sub traverse {
 	} elsif ( $file =~ /.*\.trs$/) {	# Treasure information file
 	    push(@treasure_files, $file);
 	}
-	elsif ( $file =~ /\.png$/ || $file =~ /\.xpm$/ || $file =~ /$faceExt$/) {
+	elsif ( $file =~ /\.png$/ || $file =~ /\.xpm$/ || $file =~ /\.xcf/ || $file =~ /\.doc$/ || $file =~ /\.txt$/ || $file =~ /$faceExt$/) {
 	# we cover many files we probably shouldn't, but oh well.
 	# we just don't want complaints about all of these.
 	}
 	# ignore a couple of the more common 'junk' files that are not
 	# really junk.
-	elsif (($name ne "README") && ($name ne ".svn")) {
+	elsif (($name ne "README") && ($name ne "CHANGES") && ($name ne "TODO") && ($name ne ".svn")) {
 	    $trashNum++;
 	    print "Warning: $file might be a junk file\n";
 	}
@@ -194,34 +185,27 @@ sub storeFaceInfo {
 	    $fg{$lface} = $values[0];
 	}
     }
-    if ($values[1] ne "") {
-	if ($bg{$lface} && $bg{$lface} ne $values[1]) {
-	    &warn($arch." duplicate bg color ".$bg{$lface}."/".$values[1]." face ".$lface);
-	} else {
-	    $bg{$lface} = $values[1];
-	}
-    }
-    if ($values[2] ne "" && $lface ne "blank.111" && $lface ne "empty.111") {
+    if ($values[1] ne "" && $lface ne "blank.111" && $lface ne "empty.111") {
 #      blank.111 is a special case - see above explanation
 #      Its visibility is always 0.
-	if ($visibility{$lface} && $visibility{$lface} ne $values[2]) {
-	    &warn($arch." duplicate visibilty ".$visibility{$lface}."/".$values[2]." face ".$lface);
+	if ($visibility{$lface} && $visibility{$lface} ne $values[1]) {
+	    &warn($arch." duplicate visibilty ".$visibility{$lface}."/".$values[1]." face ".$lface);
 	} else {
-	    $visibility{$lface} = $values[2];
+	    $visibility{$lface} = $values[1];
 	}
     }
-    if ($values[3] ne "" && lface ne "blank.111" && $lface ne "empty.111") {
-	if ($magicmap{$lface} && $magicmap{$lface} ne $values[3]) {
-	    &warn($arch." duplicate magicmap color ".$magicmap{$lface}."/".$values[3]." face ".$lface);
+    if ($values[2] ne "" && lface ne "blank.111" && $lface ne "empty.111") {
+	if ($magicmap{$lface} && $magicmap{$lface} ne $values[2]) {
+	    &warn($arch." duplicate magicmap color ".$magicmap{$lface}."/".$values[2]." face ".$lface);
 	} else {
-	    $magicmap{$lface} = $values[3];
+	    $magicmap{$lface} = $values[2];
 	}
     }
-    if ($values[4] ne "") {
-	if ($floor{$lface} && $floor{$lface} ne $values[4]) {
-	    &warn($arch." duplicate floor information ".$floor{$lface}."/".$values[4]." face ".$lface);
+    if ($values[3] ne "") {
+	if ($floor{$lface} && $floor{$lface} ne $values[3]) {
+	    &warn($arch." duplicate floor information ".$floor{$lface}."/".$values[3]." face ".$lface);
 	} else {
-	    $floor{$lface} = $values[4];
+	    $floor{$lface} = $values[3];
 	}
     }
 }
@@ -252,11 +236,10 @@ line:	while(<ARC>) {
 		$lface[0] = "";
 		$#lface = 0;
 		$lfg = "";
-		$lbg = "";
 		$lvis = "";
 		$mm = "";
 		$floor = "";
-		$walkon = 0;
+		$moveon = 0;
 		$nopick = 0;
 		$arch = join "_", @values;
 		$print_editor_folder = 1;
@@ -267,11 +250,11 @@ line:	while(<ARC>) {
 		if ($#lface !=0) {
 		    $#lface--;
 		    foreach $face (@lface) {
-			&storeFaceInfo($face, $lfg, $lbg, $lvis,$mm,$floor);
+			&storeFaceInfo($face, $lfg, $lvis,$mm,$floor);
 		    }
 	 	}
-		if ($walkon && !$nopick) {
-		    &warn("File $arch has an object with walk_on set which can be picked up\n");
+		if ($moveon && !$nopick) {
+		    &warn("File $arch has an object with move_on set which can be picked up\n");
 		}
 	    }
 	    # Process the color/face info now
@@ -279,10 +262,6 @@ line:	while(<ARC>) {
 		$lfg = $values[0];
 		next line;
 	    }
-	    if ($var eq "color_bg") {
-		$lbg = $values[0];
-		next line;
-	    }
 	    if ($var eq "visibility") {
 		$lvis = $values[0];
 		next line;
@@ -313,16 +292,16 @@ line:	while(<ARC>) {
 	    }
 	    elsif ($var eq "no_pick") {
 		$nopick = $values[0];
-	    } elsif ($var eq "walk_on") {
-		$walkon = $values[0];
+	    } elsif ($var eq "move_on") {
+		$moveon = 1;
 	    }
 	    elsif ($var eq "face") {
 		$lface[$#lface++] = $values[0]
 	    }
 	    elsif ($var eq "anim") {
-		if ($anim{$arch}) {
-		    &warn("$arch is a duplicate animation name");
-		    $anim{$arch}="";
+		if ($anim{"_$arch"}) {
+		    &warn("_$arch is a duplicate animation name");
+		    $anim{"_$arch"}="";
 		}
 		while (<ARC>) {
 		    chomp;
@@ -335,9 +314,9 @@ line:	while(<ARC>) {
 		    else {
 			$lface[$#lface++] = $var;
 		    }
-		    $anim{$arch} .= "$var\n";
+		    $anim{"_$arch"} .= "$var\n";
 		}
-		print ARCH "animation $arch\n";
+		print ARCH "animation _$arch\n";
 		next line;	# don't want the mina
 	    }
 	    if ($var eq "face" && ! $faces{$values[0]}) {
@@ -397,7 +376,6 @@ sub pathsOut {
 sub treasuresOut {
     foreach $treasure (@treasure_files) {
 	open(TREAS, $treasure) || &die("cannot open ".$treasure);
-	binmode(TREAS);
 	while(<TREAS>) {
 	    if (! /^\s*$/) {
 		print TREASURES $_;
@@ -416,7 +394,6 @@ sub facesOut {
 	    if ($var eq "face") {
 		$lface = $values[0];
 		$lfg = "";
-		$lbg = "";
 		$lvis = "";
 		$mm = "";
 		$floor = "";
@@ -424,9 +401,6 @@ sub facesOut {
 	    elsif ($var eq "color_fg") {
 		$lfg = $values[0];
 	    }
-	    elsif ($var eq "color_bg") {
-		$lbg = $values[0];
-	    }
 	    elsif ($var eq "visibility") {
 		$lvis = $values[0];
 	    }
@@ -437,7 +411,7 @@ sub facesOut {
 		$floor = $values[0];
 	    }
 	    elsif ($var eq "end") {
-		&storeFaceInfo($lface, $lfg, $lbg, $lvis, $mm, $floor);
+		&storeFaceInfo($lface, $lfg, $lvis, $mm, $floor);
 	    }
 	    elsif ($var eq "animation") {
 		$animation=$values[0];
@@ -471,8 +445,6 @@ sub facesOut {
 	    print FACES "face ".$face."\n";
 	    print FACES "color_fg ".$fg{$face}."\n"
 	    if $fg{$face} ne "";
-		print FACES "color_bg ".$bg{$face}."\n"
-	    if $bg{$face} ne "";
 		print FACES "visibility ".$visibility{$face}."\n"
 	    if $visibility{$face} ne "";
 		print FACES "magicmap ".$magicmap{$face}."\n"
