@@ -38,24 +38,39 @@
 #endif
 
 #include <plugin_common.h>
-enum time_enum {time_second, time_tick};
+/** Time units the animation can use. @todo add owner's speed unit */
+enum time_enum {
+    time_second,    /**< One second. */
+    time_tick       /**< One server tick. */
+};
+
+/** Result of one animation move. */
+typedef enum anim_move_result {
+    mr_finished,        /**< Move completed. */
+    mr_again            /**< Move should continue next time. */
+} anim_move_result;
+
 struct CFanimation_struct;
 struct CFmovement_struct;
-typedef int (*CFAnimRunFunc) (struct CFanimation_struct* animation, long int id, void* parameters);
-typedef long int (*CFAnimInitFunc) (char* name,char* parameters,struct CFmovement_struct*);
-typedef struct CFmovement_struct
-{
-    struct CFanimation_struct* parent;
-    CFAnimRunFunc func;
-    void* parameters;
-    long int id;
-    int tick;
-    struct CFmovement_struct* next;
+
+typedef anim_move_result (*CFAnimRunFunc)(struct CFanimation_struct *animation, long int id, void *parameters);
+
+typedef long int (*CFAnimInitFunc)(const char *name, char *parameters, struct CFmovement_struct *);
+
+/** One move in an animation. */
+typedef struct CFmovement_struct {
+    struct CFanimation_struct *parent;  /**< Animation this move is linked to. */
+    CFAnimRunFunc func;                 /**< Function to run for this move. */
+    void *parameters;                   /**< Parameters to the function. */
+    long int id;                        /**< Identifier, used for various things. */
+    int tick;                           /**< Move duration, units depending on parent's time_representation. */
+    struct CFmovement_struct *next;     /**< Next move in the animation. */
 } CFmovement;
-typedef struct CFanimation_struct
-{
-    char* name;
-    object* victim;
+
+/** One full animation. */
+typedef struct CFanimation_struct {
+    char *name;
+    object *victim;
     int paralyze;
     int invisible;
     int wizard;
@@ -63,41 +78,26 @@ typedef struct CFanimation_struct
     int verbose;
     int ghosted;
     int errors_allowed;
-    object* corpse;
+    object *corpse;
     long int tick_left;
     enum time_enum time_representation;
-    struct CFmovement_struct* nextmovement;
-    struct CFanimation_struct* nextanimation;
+    struct CFmovement_struct *nextmovement;
+    struct CFanimation_struct *nextanimation;
 } CFanimation;
-typedef struct
-{
-    const char *name;
-    CFAnimInitFunc funcinit;
-    CFAnimRunFunc funcrun;
+
+/** Available animation move. */
+typedef struct {
+    const char *name;           /**< Name as it appears in the animation file. */
+    CFAnimInitFunc funcinit;    /**< Function to process the parameters of the move. */
+    CFAnimRunFunc funcrun;      /**< Function to run the move. */
 } CFanimationHook;
+
 extern CFanimationHook animationbox[];
+
 extern int animationcount;
-int get_boolean (char* string,int* bool);
 
-typedef struct _cfpcontext
-{
-    struct _cfpcontext* down;
-    object*     who;
-    object*     activator;
-    object*     third;
-    object*     event;
-    char        message[1024];
-    int         fix;
-    int         event_code;
-    char        options[1024];
-    char        script[1024];
-    int         returnvalue;
-    int         parms[5];
-} CFPContext;
-
-extern f_plug_api  gethook;
-extern CFPContext* context_stack;
-extern CFPContext* current_context;
+#ifndef __CEXTRACT__
 #include <cfanim_proto.h>
+#endif
 
 #endif /* PLUGIN_ANIM_H */
