@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_floor_c =
- *   "$Id: floor.c 8073 2008-01-03 10:50:04Z ryo_saeba $";
+ *   "$Id: floor.c 12016 2009-06-24 19:17:15Z akirschbaum $";
  */
 
 /*
@@ -26,6 +26,10 @@
     The authors can be reached via e-mail at crossfire-devel@real-time.com
 */
 
+/**
+ * @file
+ * Floor handling.
+ */
 
 #include <global.h>
 #include <random_map.h>
@@ -54,19 +58,17 @@ static int can_propagate(char item) {
  * @param floor_arch
  * what floor to use.
  */
-static void put_floor(mapstruct* map, char** layout, int x, int y, object* floor_arch) {
+static void put_floor(mapstruct *map, char **layout, int x, int y, object *floor_arch) {
     int dx, dy;
-    object* floor;
+    object *floor;
 
     floor = arch_to_object(floor_arch->arch);
-    floor->x = x;
-    floor->y = y;
-    insert_ob_in_map(floor,map,floor,INS_NO_MERGE | INS_NO_WALK_ON);
+    object_insert_in_map_at(floor, map, floor, INS_NO_MERGE|INS_NO_WALK_ON, x, y);
 
     for (dx = -1; dx < 2; dx++) {
         for (dy = -1; dy < 2; dy++) {
-            if (GET_MAP_OB(map, x + dx, y + dy) == NULL && can_propagate(layout[x + dx][y + dy]))
-                put_floor(map, layout, x + dx, y + dy, floor_arch);
+            if (GET_MAP_OB(map, x+dx, y+dy) == NULL && can_propagate(layout[x+dx][y+dy]))
+                put_floor(map, layout, x+dx, y+dy, floor_arch);
         }
     }
 }
@@ -81,26 +83,24 @@ static void put_floor(mapstruct* map, char** layout, int x, int y, object* floor
  * parameters of the random map.
  * @return
  * Crossfire map.
- * @todo
- * use safe string functions.
  */
-mapstruct *make_map_floor(char **layout, char *floorstyle,RMParms *RP) {
-  char styledirname[256];
-  char stylefilepath[256];
-  mapstruct *style_map=0;
-  object *the_floor;
-  mapstruct *newMap =0; /* (mapstruct *) calloc(sizeof(mapstruct),1); */
-  object *thisfloor;
-  int x, y;
+mapstruct *make_map_floor(char **layout, char *floorstyle, RMParms *RP) {
+    char styledirname[256];
+    char stylefilepath[256];
+    mapstruct *style_map = NULL;
+    object *the_floor;
+    mapstruct *newMap = NULL;
+    int x, y;
 
-  /* allocate the map */
-  newMap = get_empty_map(RP->Xsize,RP->Ysize);
+    /* allocate the map */
+    newMap = get_empty_map(RP->Xsize, RP->Ysize);
 
-  /* get the style map */
-  sprintf(styledirname,"%s","/styles/floorstyles");
-  sprintf(stylefilepath,"%s/%s",styledirname,floorstyle);
-  style_map = find_style(styledirname,floorstyle,-1);
-  if(style_map == 0) return newMap;
+    /* get the style map */
+    snprintf(styledirname, sizeof(styledirname), "%s", "/styles/floorstyles");
+    snprintf(stylefilepath, sizeof(stylefilepath), "%s/%s", styledirname, floorstyle);
+    style_map = find_style(styledirname, floorstyle, -1);
+    if (style_map == NULL)
+        return newMap;
 
     if (RP->multiple_floors) {
         for (x = 0; x < RP->Xsize; x++) {
@@ -112,14 +112,15 @@ mapstruct *make_map_floor(char **layout, char *floorstyle,RMParms *RP) {
     }
 
     /* fill up the map with the given floor style */
-    if ((the_floor=pick_random_object(style_map))!=NULL) {
-        for(x=0;x<RP->Xsize;x++)
-            for(y=0;y<RP->Ysize;y++) {
+    if ((the_floor = pick_random_object(style_map)) != NULL) {
+        object *thisfloor;
+
+        for (x = 0; x < RP->Xsize; x++)
+            for (y = 0; y < RP->Ysize; y++) {
                 if (GET_MAP_OB(newMap, x, y) != NULL)
                     continue;
                 thisfloor = arch_to_object(the_floor->arch);
-                thisfloor->x = x; thisfloor->y = y;
-                insert_ob_in_map(thisfloor,newMap,thisfloor,INS_NO_MERGE | INS_NO_WALK_ON);
+                object_insert_in_map_at(thisfloor, newMap, thisfloor, INS_NO_MERGE|INS_NO_WALK_ON, x, y);
             }
     }
     return newMap;
