@@ -1,6 +1,6 @@
 /* random_map.c */
 extern void dump_layout(char **layout, RMParms *RP);
-extern mapstruct *generate_random_map(const char *OutFileName, RMParms *RP, char** use_layout);
+extern mapstruct *generate_random_map(const char *OutFileName, RMParms *RP, char **use_layout);
 extern char **layoutgen(RMParms *RP);
 extern char **symmetrize_layout(char **maze, int sym, RMParms *RP);
 extern char **rotate_layout(char **maze, int rotation, RMParms *RP);
@@ -8,8 +8,8 @@ extern void roomify_layout(char **maze, RMParms *RP);
 extern int can_make_wall(char **maze, int dx, int dy, int dir, RMParms *RP);
 extern int make_wall(char **maze, int x, int y, int dir);
 extern void doorify_layout(char **maze, RMParms *RP);
-extern void write_map_parameters_to_string(char *buf, RMParms *RP);
-extern void write_parameters_to_string(char *buf, int xsize_n, int ysize_n, char *wallstyle_n, char *floorstyle_n, char *monsterstyle_n, char *treasurestyle_n, char *layoutstyle_n, char *decorstyle_n, char *doorstyle_n, char *exitstyle_n, char *final_map_n, char *exit_on_final_map_n, char *this_map_n, int layoutoptions1_n, int layoutoptions2_n, int layoutoptions3_n, int symmetry_n, int dungeon_depth_n, int dungeon_level_n, int difficulty_n, int difficulty_given_n, int decoroptions_n, int orientation_n, int origin_x_n, int origin_y_n, int random_seed_n, int treasureoptions_n, float difficulty_increase);
+extern void write_map_parameters_to_string(RMParms *RP, char *buf, int size);
+extern void write_parameters_to_string(char *buf, int xsize_n, int ysize_n, const char *wallstyle_n, const char *floorstyle_n, const char *monsterstyle_n, const char *treasurestyle_n, const char *layoutstyle_n, const char *decorstyle_n, const char *doorstyle_n, const char *exitstyle_n, const char *final_map_n, const char *exit_on_final_map_n, const char *this_map_n, int layoutoptions1_n, int layoutoptions2_n, int layoutoptions3_n, int symmetry_n, int dungeon_depth_n, int dungeon_level_n, int difficulty_n, int difficulty_given_n, int decoroptions_n, int orientation_n, int origin_x_n, int origin_y_n, int random_seed_n, int treasureoptions_n, float difficulty_increase);
 /* room_gen_onion.c */
 extern char **map_gen_onion(int xsize, int ysize, int option, int layers);
 extern void centered_onion(char **maze, int xsize, int ysize, int option, int layers);
@@ -22,11 +22,6 @@ extern char **map_gen_spiral(int xsize, int ysize, int option);
 extern void connect_spirals(int xsize, int ysize, int sym, char **layout);
 /* maze_gen.c */
 extern char **maze_gen(int xsize, int ysize, int option);
-extern void make_wall_free_list(int xsize, int ysize);
-extern void pop_wall_point(int *x, int *y);
-extern int find_free_point(char **maze, int *x, int *y, int xc, int yc, int xsize, int ysize);
-extern void fill_maze_full(char **maze, int x, int y, int xsize, int ysize);
-extern void fill_maze_sparse(char **maze, int x, int y, int xsize, int ysize);
 /* floor.c */
 extern mapstruct *make_map_floor(char **layout, char *floorstyle, RMParms *RP);
 /* wall.c */
@@ -58,7 +53,6 @@ extern object *find_closest_monster(mapstruct *map, int x, int y, RMParms *RP);
 extern int keyplace(mapstruct *map, int x, int y, char *keycode, int door_flag, int n_keys, RMParms *RP);
 extern object *find_monster_in_room_recursive(char **layout, mapstruct *map, int x, int y, RMParms *RP);
 extern object *find_monster_in_room(mapstruct *map, int x, int y, RMParms *RP);
-extern void find_spot_in_room_recursive(char **layout, int x, int y, RMParms *RP);
 extern int find_spot_in_room(mapstruct *map, int x, int y, int *kx, int *ky, RMParms *RP);
 extern void find_enclosed_spot(mapstruct *map, int *cx, int *cy, RMParms *RP);
 extern void remove_monsters(int x, int y, mapstruct *map);
@@ -82,9 +76,9 @@ extern void free_style_maps(void);
 extern int surround_check(char **layout, int i, int j, int Xsize, int Ysize);
 extern char **roguelike_layout_gen(int xsize, int ysize, int options);
 /* snake.c */
-extern char **make_snake_layout(int xsize, int ysize, int options);
+extern char **make_snake_layout(int xsize, int ysize);
 /* square_spiral.c */
 extern void find_top_left_corner(char **maze, int *cx, int *cy);
-extern char **make_square_spiral_layout(int xsize, int ysize, int options);
+extern char **make_square_spiral_layout(int xsize, int ysize);
 /* expand2x.c */
 extern char **expand2x(char **layout, int xsize, int ysize);
